ScopfDeviceRow

Struct ScopfDeviceRow 

#[non_exhaustive]
pub struct ScopfDeviceRow {
Show 42 fields pub bus: BusId, pub uid: String, pub c_on: f64, pub c_su: f64, pub c_sd: f64, pub p_ru: f64, pub p_rd: f64, pub p_ru_su: f64, pub p_rd_sd: f64, pub c_rgu: Vec<f64>, pub c_rgd: Vec<f64>, pub c_scr: Vec<f64>, pub c_nsc: Vec<f64>, pub c_rru_on: Vec<f64>, pub c_rru_off: Vec<f64>, pub c_rrd_on: Vec<f64>, pub c_rrd_off: Vec<f64>, pub c_qru: Vec<f64>, pub c_qrd: Vec<f64>, pub p_rgu_max: f64, pub p_rgd_max: f64, pub p_scr_max: f64, pub p_nsc_max: f64, pub p_rru_on_max: f64, pub p_rru_off_max: f64, pub p_rrd_on_max: f64, pub p_rrd_off_max: f64, pub p_0: f64, pub q_0: f64, pub p_max: Vec<f64>, pub p_min: Vec<f64>, pub q_max: Vec<f64>, pub q_min: Vec<f64>, pub sus: Vec<Vec<f64>>, pub q_bound_cap: i64, pub q_linear_cap: i64, pub beta_ub: Option<f64>, pub beta_lb: Option<f64>, pub q_0_ub: Option<f64>, pub q_0_lb: Option<f64>, pub beta: Option<f64>, pub q_p0: Option<f64>,
}
One simple dispatchable device row.

Producers and consumers share this layout. Vector fields use the internal zero based period order.

The reactive capability block is the q_bound_cap/q_linear_cap pair and the parameters of the mode each one selects. The two modes are mutually exclusive and a device can select neither. A parameter of a mode the device did not select is None. Read the two flags before the parameters.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
bus: BusIduid: Stringc_on: f64c_su: f64c_sd: f64p_ru: f64p_rd: f64p_ru_su: f64p_rd_sd: f64c_rgu: Vec<f64>c_rgd: Vec<f64>c_scr: Vec<f64>c_nsc: Vec<f64>c_rru_on: Vec<f64>c_rru_off: Vec<f64>c_rrd_on: Vec<f64>c_rrd_off: Vec<f64>c_qru: Vec<f64>c_qrd: Vec<f64>p_rgu_max: f64p_rgd_max: f64p_scr_max: f64p_nsc_max: f64p_rru_on_max: f64p_rru_off_max: f64p_rrd_on_max: f64p_rrd_off_max: f64p_0: f64q_0: f64p_max: Vec<f64>p_min: Vec<f64>q_max: Vec<f64>q_min: Vec<f64>sus: Vec<Vec<f64>>q_bound_cap: i64q_linear_cap: i64beta_ub: Option<f64>beta_lb: Option<f64>q_0_ub: Option<f64>q_0_lb: Option<f64>beta: Option<f64>q_p0: Option<f64>

The intercept of the linear capability line. The GOC3 document calls this q_0, which this row already uses for initial_status.q.