ScopfInstance

Struct ScopfInstance 

#[non_exhaustive]
pub struct ScopfInstance { pub static_data: ScopfStaticData, pub lengths: ScopfLengths, pub energy_windows: ScopfEnergyWindows, pub price_blocks: ScopfPriceBlocks, pub ac_contingency_survivors: ScopfAcContingencySurvivors, pub dc_contingency_flows: Vec<ScopfDcContingencyFlowRow>, pub violation_cost: ScopfViolationCost, pub device_class_layout: ScopfDeviceClassLayout, }
Matrix free SCOPF input data.

Internal class, period, contingency, window, and flattened row indices are zero based and follow the source document order of the section that owns them. Source UIDs and external bus IDs remain separate fields.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
static_data: ScopfStaticData

Buses, branches, devices, controls, reserves, and memberships.

lengths: ScopfLengthsenergy_windows: ScopfEnergyWindowsprice_blocks: ScopfPriceBlocksac_contingency_survivors: ScopfAcContingencySurvivorsdc_contingency_flows: Vec<ScopfDcContingencyFlowRow>violation_cost: ScopfViolationCostdevice_class_layout: ScopfDeviceClassLayout