#[non_exhaustive]pub struct ScopfVariableRatioRow {
pub j_xf: usize,
pub tau_min: f64,
pub tau_max: f64,
}Expand description
A transformer with a variable winding ratio control range (vwr).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.j_xf: usizetau_min: f64tau_max: f64Trait Implementations
Sourceimpl Clone for ScopfVariableRatioRow
impl Clone for ScopfVariableRatioRow
Sourcefn clone(&self) -> ScopfVariableRatioRow
fn clone(&self) -> ScopfVariableRatioRow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScopfVariableRatioRow
impl Debug for ScopfVariableRatioRow
Sourceimpl<'de> Deserialize<'de> for ScopfVariableRatioRow
impl<'de> Deserialize<'de> for ScopfVariableRatioRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ScopfVariableRatioRow
impl PartialEq for ScopfVariableRatioRow
Sourcefn eq(&self, other: &ScopfVariableRatioRow) -> bool
fn eq(&self, other: &ScopfVariableRatioRow) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ScopfVariableRatioRow
impl Serialize for ScopfVariableRatioRow
impl StructuralPartialEq for ScopfVariableRatioRow