#[non_exhaustive]pub struct ScopfViolationCost {
pub p_bus: Option<f64>,
pub q_bus: Option<f64>,
pub s: Option<f64>,
pub e: Option<f64>,
}Expand description
The case’s four violation prices. The GOC3 document spells them
p_bus_vio_cost, q_bus_vio_cost, s_vio_cost, and e_vio_cost under
network.violation_cost. Any one of them can be absent and is then None:
GOCompetition’s 14 bus validation case has no e_vio_cost.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.p_bus: Option<f64>q_bus: Option<f64>s: Option<f64>e: Option<f64>Trait Implementations
Sourceimpl Clone for ScopfViolationCost
impl Clone for ScopfViolationCost
Sourcefn clone(&self) -> ScopfViolationCost
fn clone(&self) -> ScopfViolationCost
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScopfViolationCost
impl Debug for ScopfViolationCost
Sourceimpl<'de> Deserialize<'de> for ScopfViolationCost
impl<'de> Deserialize<'de> for ScopfViolationCost
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ScopfViolationCost
impl PartialEq for ScopfViolationCost
Sourcefn eq(&self, other: &ScopfViolationCost) -> bool
fn eq(&self, other: &ScopfViolationCost) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ScopfViolationCost
impl Serialize for ScopfViolationCost
impl Copy for ScopfViolationCost
impl StructuralPartialEq for ScopfViolationCost